# mason_image [![Version][version-badge]][version-link] ![MIT License][license-badge]
A small tool to mess up a image

`mason_image` is a small tool to mess up a image


### Demo

Before

![](https://raw.githubusercontent.com/Mason-Lin/mason_image/master/lenna_in.jpg)

After

![](https://raw.githubusercontent.com/Mason-Lin/mason_image/master/lenna_out.jpg)


### Usage

```
usage: mason_image [-h] [--in IN_IMAGE] [--out OUT_IMAGE]

optional arguments:
  -h, --help         show this help message and exit
  --in IN_IMAGE      path of image to mess up
  --out OUT_IMAGE    path of output image
```


### Install

```
$ pip install mason_image
```

### License

[MIT](https://github.com/Mason-Lin/mason_image/blob/master/LICENSE)

[version-badge]:   https://img.shields.io/badge/version-0.1.0-brightgreen.svg
[version-link]:    https://pypi.python.org/pypi/mason_image/
[license-badge]:   https://img.shields.io/github/license/Mason-Lin/mason_image.svg


